@@ -36,13 +36,13 @@
 #include <kpassivepopup.h>
 #include <klineedit.h>
 
-#include <ntqtextedit.h>
-#include <ntqcolor.h>
-#include <ntqlistview.h>
-#include <ntqpushbutton.h>
-#include <ntqheader.h>
-#include <ntqtoolbutton.h>
-#include <ntqaction.h>
+#include <tqtextedit.h>
+#include <tqcolor.h>
+#include <tqlistview.h>
+#include <tqpushbutton.h>
+#include <tqheader.h>
+#include <tqtoolbutton.h>
+#include <tqaction.h>
 
 #include "Q_colorspreferencesdialog.h"
 #include "Q_generalpreferencesdialog.h"
@@ -278,9 +278,9 @@ void Kasablanca::optionsPreferences()
 
 	dialog->setHelp("globalhelp");
 
-	KasablancaGeneralPreferencesDialog *general = new KasablancaGeneralPreferencesDialog(0, i18n("General"));
-	KasablancaColorsPreferencesDialog *colors = new KasablancaColorsPreferencesDialog(0, i18n("Colors"));
-	KasablancaUserInterfacePreferencesDialog *ui = new KasablancaUserInterfacePreferencesDialog(0, i18n("User Interface"));
+	KasablancaGeneralPreferencesDialog *general = new KasablancaGeneralPreferencesDialog(0, i18n("General").utf8());
+	KasablancaColorsPreferencesDialog *colors = new KasablancaColorsPreferencesDialog(0, i18n("Colors").utf8());
+	KasablancaUserInterfacePreferencesDialog *ui = new KasablancaUserInterfacePreferencesDialog(0, i18n("User Interface").utf8());
 	dialog->addPage(general, i18n("General"), "kasablanca");
 	dialog->addPage(colors, i18n("Colors"), "colors");
 	dialog->addPage(ui, i18n("User Interface"), "winprops");
